@@ -2,8 +2,8 @@
  *
  * NOTIFICATIONS.C - Nagios Notifications CGI
  *
- * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 06-19-2006
+ * Copyright (c) 1999-2008 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 01-08-2008
  *
  * This CGI program will display the notification events for 
  * a given host or contact or for all contacts/hosts.
@@ -231,6 +231,7 @@ int main(void){
 			printf("<option value=%d %s>All service notifications\n",NOTIFICATION_SERVICE_ALL,(notification_options==NOTIFICATION_SERVICE_ALL)?"selected":"");
 			printf("<option value=%d %s>All host notifications\n",NOTIFICATION_HOST_ALL,(notification_options==NOTIFICATION_HOST_ALL)?"selected":"");
 	                }
+		printf("<option value=%d %s>Service custom\n",NOTIFICATION_SERVICE_CUSTOM,(notification_options==NOTIFICATION_SERVICE_CUSTOM)?"selected":"");
 		printf("<option value=%d %s>Service acknowledgements\n",NOTIFICATION_SERVICE_ACK,(notification_options==NOTIFICATION_SERVICE_ACK)?"selected":"");
 		printf("<option value=%d %s>Service warning\n",NOTIFICATION_SERVICE_WARNING,(notification_options==NOTIFICATION_SERVICE_WARNING)?"selected":"");
 		printf("<option value=%d %s>Service unknown\n",NOTIFICATION_SERVICE_UNKNOWN,(notification_options==NOTIFICATION_SERVICE_UNKNOWN)?"selected":"");
@@ -238,6 +239,7 @@ int main(void){
 		printf("<option value=%d %s>Service recovery\n",NOTIFICATION_SERVICE_RECOVERY,(notification_options==NOTIFICATION_SERVICE_RECOVERY)?"selected":"");
 		printf("<option value=%d %s>Service flapping\n",NOTIFICATION_SERVICE_FLAP,(notification_options==NOTIFICATION_SERVICE_FLAP)?"selected":"");
 		if(query_type!=FIND_SERVICE){
+			printf("<option value=%d %s>Host custom\n",NOTIFICATION_HOST_CUSTOM,(notification_options==NOTIFICATION_HOST_CUSTOM)?"selected":"");
 			printf("<option value=%d %s>Host acknowledgements\n",NOTIFICATION_HOST_ACK,(notification_options==NOTIFICATION_HOST_ACK)?"selected":"");
 			printf("<option value=%d %s>Host down\n",NOTIFICATION_HOST_DOWN,(notification_options==NOTIFICATION_HOST_DOWN)?"selected":"");
 			printf("<option value=%d %s>Host unreachable\n",NOTIFICATION_HOST_UNREACHABLE,(notification_options==NOTIFICATION_HOST_UNREACHABLE)?"selected":"");
@@ -308,6 +310,7 @@ void document_header(int use_stylesheet){
 
 	printf("<html>\n");
 	printf("<head>\n");
+	printf("<link rel=\"shortcut icon\" href=\"%sfavicon.ico\" type=\"image/ico\">\n",url_images_path);
 	printf("<title>\n");
 	printf("Alert Notifications\n");
 	printf("</title>\n");
@@ -367,10 +370,11 @@ int process_cgivars(void){
 				error=TRUE;
 				break;
 			        }
-
-			query_host_name=strdup(variables[x]);
-			if(query_host_name==NULL)
+	
+			if((query_host_name=strdup(variables[x]))==NULL)
 				query_host_name="";
+			strip_html_brackets(query_host_name);
+
 			if(!strcmp(query_host_name,"all"))
 				find_all=TRUE;
 			else
@@ -386,10 +390,10 @@ int process_cgivars(void){
 				break;
 			        }
 
-			query_contact_name=strdup(variables[x]);
-
-			if(query_contact_name==NULL)
+			if((query_contact_name=strdup(variables[x]))==NULL)
 				query_contact_name="";
+			strip_html_brackets(query_contact_name);
+
 			if(!strcmp(query_contact_name,"all"))
 				find_all=TRUE;
 			else
@@ -404,10 +408,9 @@ int process_cgivars(void){
 				error=TRUE;
 				break;
 			        }
-
-			query_svc_description=strdup(variables[x]);
-			if(query_svc_description==NULL)
+			if((query_svc_description=strdup(variables[x]))==NULL)
 				query_svc_description="";
+			strip_html_brackets(query_svc_description);
 		        }
 	
 		/* we found the notification type argument */
@@ -457,7 +460,7 @@ int process_cgivars(void){
 
 
 void display_notifications(void){
-	mmapfile *thefile;
+	mmapfile *thefile=NULL;
 	char *input=NULL;
 	char *temp_buffer;
 	char date_time[MAX_DATETIME_LENGTH];
@@ -553,7 +556,7 @@ void display_notifications(void){
 			/* get the host name */
 			temp_buffer=(char *)strtok(NULL,";");
 			snprintf(host_name,sizeof(host_name),"%s",(temp_buffer==NULL)?"":temp_buffer);
-			host_name[sizeof(host_name)]='\x0';
+			host_name[sizeof(host_name)-1]='\x0';
 
 			/* get the service name */
 			if(notification_type==SERVICE_NOTIFICATION){
@@ -582,6 +585,10 @@ void display_notifications(void){
 					notification_detail_type=NOTIFICATION_SERVICE_RECOVERY;
 					strcpy(alert_level_class,"OK");
 				        }
+				else if(strstr(alert_level,"CUSTOM (")){
+					notification_detail_type=NOTIFICATION_SERVICE_CUSTOM;
+					strcpy(alert_level_class,"CUSTOM");
+				        }
 				else if(strstr(alert_level,"ACKNOWLEDGEMENT (")){
 					notification_detail_type=NOTIFICATION_SERVICE_ACK;
 					strcpy(alert_level_class,"ACKNOWLEDGEMENT");
@@ -620,6 +627,10 @@ void display_notifications(void){
 					strcpy(alert_level_class,"HOSTUP");
 					notification_detail_type=NOTIFICATION_HOST_RECOVERY;
 				        }
+				else if(strstr(alert_level,"CUSTOM (")){
+					strcpy(alert_level_class,"HOSTCUSTOM");
+					notification_detail_type=NOTIFICATION_HOST_CUSTOM;
+				        }
 				else if(strstr(alert_level,"ACKNOWLEDGEMENT (")){
 					strcpy(alert_level_class,"HOSTACKNOWLEDGEMENT");
 					notification_detail_type=NOTIFICATION_HOST_ACK;
@@ -714,7 +725,7 @@ void display_notifications(void){
 				printf("<td CLASS='notifications%s'>%s</td>\n",(odd)?"Even":"Odd",date_time);
 				printf("<td CLASS='notifications%s'><a href='%s?type=contacts#%s'>%s</a></td>\n",(odd)?"Even":"Odd",CONFIG_CGI,url_encode(contact_name),contact_name);
 				printf("<td CLASS='notifications%s'><a href='%s?type=commands#%s'>%s</a></td>\n",(odd)?"Even":"Odd",CONFIG_CGI,url_encode(method_name),method_name);
-				printf("<td CLASS='notifications%s'>%s</td>\n",(odd)?"Even":"Odd",temp_buffer);
+				printf("<td CLASS='notifications%s'>%s</td>\n",(odd)?"Even":"Odd",html_encode(temp_buffer,FALSE));
 				printf("</tr>\n");
 			        }
 		        }
