@@ -2,8 +2,8 @@
  *
  * SHOWLOG.C - Nagios Log File CGI
  *
- * Copyright (c) 1999-2007 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 04-10-2007
+ * Copyright (c) 1999-2008 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 01-08-2008
  *
  * This CGI program will display the contents of the Nagios
  * log file.
@@ -33,11 +33,14 @@
 #include "../include/cgiauth.h"
 
 extern char   main_config_file[MAX_FILENAME_LENGTH];
+extern char   url_html_path[MAX_FILENAME_LENGTH];
 extern char   url_images_path[MAX_FILENAME_LENGTH];
 extern char   url_stylesheets_path[MAX_FILENAME_LENGTH];
 
 extern int    log_rotation_method;
 
+extern int    enable_splunk_integration;
+
 void document_header(int);
 void document_footer(void);
 int process_cgivars(void);
@@ -192,6 +195,7 @@ void document_header(int use_stylesheet){
 
 	printf("<HTML>\n");
 	printf("<HEAD>\n");
+	printf("<link rel=\"shortcut icon\" href=\"%sfavicon.ico\" type=\"image/ico\">\n",url_images_path);
 	printf("<TITLE>\n");
 	printf("Nagios Log File\n");
 	printf("</TITLE>\n");
@@ -294,13 +298,13 @@ int display_log(void){
 	char image[MAX_INPUT_BUFFER];
 	char image_alt[MAX_INPUT_BUFFER];
 	time_t t;
-	char *temp_buffer;
+	char *temp_buffer=NULL;
 	char date_time[MAX_DATETIME_LENGTH];
-	int error;
-	mmapfile *thefile;
+	int error=FALSE;
+	mmapfile *thefile=NULL;
 	char last_message_date[MAX_INPUT_BUFFER]="";
 	char current_message_date[MAX_INPUT_BUFFER]="";
-	struct tm *time_ptr;
+	struct tm *time_ptr=NULL;
 
 
 	/* check to see if the user is authorized to view the log file */
@@ -420,6 +424,14 @@ int display_log(void){
 				strcpy(image,EXTERNAL_COMMAND_ICON);
 				strcpy(image_alt,EXTERNAL_COMMAND_ICON_ALT);
 			        }
+			else if(strstr(input,"PASSIVE SERVICE CHECK:")){
+				strcpy(image,PASSIVE_ICON);
+				strcpy(image_alt,"Passive Service Check");
+			        }
+			else if(strstr(input,"PASSIVE HOST CHECK:")){
+				strcpy(image,PASSIVE_ICON);
+				strcpy(image_alt,"Passive Host Check");
+			        }
 			else if(strstr(input,"LOG ROTATION:")){
 				strcpy(image,LOG_ROTATION_ICON);
 				strcpy(image_alt,LOG_ROTATION_ICON_ALT);
@@ -513,7 +525,12 @@ int display_log(void){
 			
 			if(display_frills==TRUE)
 				printf("<img align='left' src='%s%s' alt='%s' title='%s'>",url_images_path,image,image_alt,image_alt);
-			printf("[%s] %s<br clear='all'>\n",date_time,(temp_buffer==NULL)?"":strip_plugin_html(temp_buffer));
+			printf("[%s] %s",date_time,(temp_buffer==NULL)?"":html_encode(temp_buffer,FALSE));
+			if(enable_splunk_integration==TRUE){
+				printf("&nbsp;&nbsp;&nbsp;");
+				display_splunk_generic_url(temp_buffer,2);
+				}
+			printf("<br clear='all'>\n");
 		        }
 
 		printf("</DIV></P>\n");
@@ -530,3 +547,4 @@ int display_log(void){
 
 	return OK;
         }
+
