@@ -3,7 +3,7 @@
  * STATUSWML.C -  Nagios Status CGI for WAP-enabled devices
  *
  * Copyright (c) 2001-2007 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 01-18-2007
+ * Last Modified: 12-13-2007
  *
  * License:
  * 
@@ -234,11 +234,9 @@ int process_cgivars(void){
 				break;
 			        }
 
-			hostgroup_name=(char *)malloc(strlen(variables[x])+1);
-			if(hostgroup_name==NULL)
+			if((hostgroup_name=(char *)strdup(variables[x]))==NULL)
 				hostgroup_name="";
-			else
-				strcpy(hostgroup_name,variables[x]);
+			strip_html_brackets(hostgroup_name);
 
 			if(!strcmp(hostgroup_name,"all"))
 				show_all_hostgroups=TRUE;
@@ -255,11 +253,9 @@ int process_cgivars(void){
 				break;
 			        }
 
-			host_name=(char *)malloc(strlen(variables[x])+1);
-			if(host_name==NULL)
+			if((host_name=(char *)strdup(variables[x]))==NULL)
 				host_name="";
-			else
-				strcpy(host_name,variables[x]);
+			strip_html_brackets(host_name);
 		        }
 
 		/* we found the service argument */
@@ -271,11 +267,9 @@ int process_cgivars(void){
 				break;
 			        }
 
-			service_desc=(char *)malloc(strlen(variables[x])+1);
-			if(service_desc==NULL)
+			if((service_desc=(char *)strdup(variables[x]))==NULL)
 				service_desc="";
-			else
-				strcpy(service_desc,variables[x]);
+			strip_html_brackets(service_desc);
 		        }
 
 
@@ -312,11 +306,9 @@ int process_cgivars(void){
 				break;
 			        }
 
-			ping_address=(char *)malloc(strlen(variables[x])+1);
-			if(ping_address==NULL)
+			if((ping_address=(char *)strdup(variables[x]))==NULL)
 				ping_address="";
-			else
-				strcpy(ping_address,variables[x]);
+			strip_html_brackets(ping_address);
 		        }
 
 		/* we found the traceroute argument */
@@ -328,11 +320,9 @@ int process_cgivars(void){
 				break;
 			        }
 
-			traceroute_address=(char *)malloc(strlen(variables[x])+1);
-			if(traceroute_address==NULL)
+			if((traceroute_address=(char *)strdup(variables[x]))==NULL)
 				traceroute_address="";
-			else
-				strcpy(traceroute_address,variables[x]);
+			strip_html_brackets(traceroute_address);
 		        }
 
 	        }
@@ -607,7 +597,7 @@ void display_quick_stats(void){
 /* displays hostgroup status overview */
 void display_hostgroup_overview(void){
 	hostgroup *temp_hostgroup;
-	hostgroupmember *temp_member;
+	hostsmember *temp_member;
 	host *temp_host;
 	hoststatus *temp_hoststatus;
 
@@ -678,7 +668,7 @@ void display_hostgroup_overview(void){
 /* displays hostgroup status summary */
 void display_hostgroup_summary(void){
 	hostgroup *temp_hostgroup;
-	hostgroupmember *temp_member;
+	hostsmember *temp_member;
 	host *temp_host;
 	hoststatus *temp_hoststatus;
 	service *temp_service;
@@ -971,9 +961,9 @@ void display_host(void){
 
 	printf("<p align='center' mode='wrap'>\n");
 	printf("<b>Your Name:</b><br/>\n");
-	printf("<input name='name'/><br/>\n");
+	printf("<input name='name' value='%s' /><br/>\n",getenv("REMOTE_USER"));
 	printf("<b>Comment:</b><br/>\n");
-	printf("<input name='comment'/>\n");
+	printf("<input name='comment' value='acknowledged by WAP'/>\n");
 
 	printf("<do type='accept'>\n");
 	printf("<go href='%s' method='post'><postfield name='host' value='%s'/><postfield name='com_author' value='$(name)'/><postfield name='com_data' value='$(comment)'/><postfield name='persistent' value=''/><postfield name='send_notification' value=''/><postfield name='cmd_typ' value='%d'/><postfield name='cmd_mod' value='%d'/><postfield name='content' value='wml'/></go>\n",COMMAND_CGI,host_name,CMD_ACKNOWLEDGE_HOST_PROBLEM,CMDMODE_COMMIT);
@@ -1177,9 +1167,9 @@ void display_service(void){
 
 	printf("<p align='center' mode='wrap'>\n");
 	printf("<b>Your Name:</b><br/>\n");
-	printf("<input name='name'/><br/>\n");
+	printf("<input name='name' value='%s' /><br/>\n",getenv("REMOTE_USER"));
 	printf("<b>Comment:</b><br/>\n");
-	printf("<input name='comment'/>\n");
+	printf("<input name='comment' value='acknowledged by WAP'/>\n");
 
 	printf("<do type='accept'>\n");
 	printf("<go href='%s' method='post'><postfield name='host' value='%s'/><postfield name='service' value='%s'/><postfield name='com_author' value='$(name)'/><postfield name='com_data' value='$(comment)'/><postfield name='persistent' value=''/><postfield name='send_notification' value=''/><postfield name='cmd_typ' value='%d'/><postfield name='cmd_mod' value='%d'/><postfield name='content' value='wml'/></go>\n",COMMAND_CGI,host_name,service_desc,CMD_ACKNOWLEDGE_SVC_PROBLEM,CMDMODE_COMMIT);
